@@ -2,7 +2,7 @@
 /*                                                                          */
 /*  The FreeType project -- a free and portable quality TrueType renderer.  */
 /*                                                                          */
-/*  Copyright 2005, 2006 by                                                 */
+/*  Copyright 2005, 2006, 2009, 2011-2013 by                                */
 /*  D. Turner, R.Wilhelm, and W. Lemberg                                    */
 /*                                                                          */
 /*                                                                          */
@@ -21,6 +21,7 @@
 #include FT_CACHE_MANAGER_H
 
 #include FT_GLYPH_H
+#include FT_STROKER_H
 #include FT_BITMAP_H
 
 #include <stdlib.h>
@@ -57,6 +58,13 @@
   /*************************************************************************/
 
 
+  /* default window dimensions */
+#define DIM_X  640
+#define DIM_Y  480
+
+  /* baseline distance between header lines */
+#define HEADER_HEIGHT  12
+
 #include "graph.h"
 #include "grobjs.h"
 #include "grfont.h"
@@ -67,12 +75,15 @@
     grBitmap*   bitmap;
     grColor     fore_color;
     grColor     back_color;
+    grColor     warn_color;
 
   } FTDemo_Display;
 
 
   FTDemo_Display*
-  FTDemo_Display_New( grPixelMode  mode );
+  FTDemo_Display_New( grPixelMode  mode,
+                      int          width,
+                      int          height );
 
 
   void
@@ -157,47 +168,48 @@
 
   typedef struct
   {
-    FT_Library        library;           /* the FreeType library            */
-    FTC_Manager       cache_manager;     /* the cache manager               */
-    FTC_ImageCache    image_cache;       /* the glyph image cache           */
-    FTC_SBitCache     sbits_cache;       /* the glyph small bitmaps cache   */
-    FTC_CMapCache     cmap_cache;        /* the charmap cache..             */
+    FT_Library      library;           /* the FreeType library          */
+    FTC_Manager     cache_manager;     /* the cache manager             */
+    FTC_ImageCache  image_cache;       /* the glyph image cache         */
+    FTC_SBitCache   sbits_cache;       /* the glyph small bitmaps cache */
+    FTC_CMapCache   cmap_cache;        /* the charmap cache             */
 
-    PFont*            fonts;             /* installed fonts */
-    int               num_fonts;
-    int               max_fonts;
+    PFont*          fonts;             /* installed fonts */
+    int             num_fonts;
+    int             max_fonts;
 
-    int               use_sbits_cache;   /* toggle sbits cache */
+    int             use_sbits_cache;   /* toggle sbits cache */
 
     /* use FTDemo_Set_Current_XXX to set the following two fields */
-    PFont             current_font;      /* selected font */
-    FTC_ScalerRec     scaler;
-    FT_ULong          load_flags;
+    PFont           current_font;      /* selected font */
+    FTC_ScalerRec   scaler;
+    FT_ULong        load_flags;
 
     /* call FTDemo_Update_Current_Flags after setting any of the following fields */
-    int               hinted;            /* is glyph hinting active?    */
-    int               antialias;         /* is anti-aliasing active?    */
-    int               use_sbits;         /* do we use embedded bitmaps? */
-    int               low_prec;          /* force low precision         */
-    int               autohint;          /* force auto-hinting          */
-    int               lcd_mode;
-    int               preload;           /* force font file preloading */
+    int             hinted;            /* is glyph hinting active?    */
+    int             antialias;         /* is anti-aliasing active?    */
+    int             use_sbits;         /* do we use embedded bitmaps? */
+    int             autohint;          /* force auto-hinting          */
+    int             lcd_mode;
+    int             preload;           /* force font file preloading  */
+    int             color;             /* load color bitmaps          */
 
     /* don't touch the following fields! */
 
     /* used for string rendering */
-    TGlyph            string[MAX_GLYPHS];
-    int               string_length;
-    int               string_reload;
+    TGlyph          string[MAX_GLYPHS];
+    int             string_length;
+    int             string_reload;
 
-    FT_Encoding       encoding;
-    FT_Bitmap         bitmap;            /* used as bitmap conversion buffer */
+    FT_Encoding     encoding;
+    FT_Stroker      stroker;
+    FT_Bitmap       bitmap;            /* used as bitmap conversion buffer */
 
   } FTDemo_Handle;
 
 
   FTDemo_Handle*
-  FTDemo_New( FT_Encoding  encoding );
+  FTDemo_New( void );
 
 
   void
@@ -222,11 +234,6 @@
   FTDemo_Set_Current_Size( FTDemo_Handle*  handle,
                            int             pixel_size );
 
-  void
-  FTDemo_Set_Current_Pointsize( FTDemo_Handle*  handle,
-                                int             point_size,
-                                int             res );
-
   void
   FTDemo_Set_Current_Charsize( FTDemo_Handle*  handle,
                                int             point_size,
@@ -309,8 +316,8 @@
 
   /* set the string to be drawn */
   void
-  FTDemo_String_Set( FTDemo_Handle*        handle,
-                     const unsigned char*  string );
+  FTDemo_String_Set( FTDemo_Handle*  handle,
+                     const char*     string );
 
 
   /* draw a string centered at (center_x, center_y) --  */
